# Copyright (c) Ely Deckers.
#
# This source code is licensed under the MPL-2.0 license found in the
# LICENSE file in the root directory of this source tree.


class ApiInterface:
    def get_system_config(self):
        pass

    def get_lights(self):
        pass

    def get_sensors(self):
        pass

    def get_batteries(self):
        pass
