# Copyright (c) Ely Deckers.
#
# This source code is licensed under the MPL-2.0 license found in the
# LICENSE file in the root directory of this source tree.

DEFAULT_MAX_CACHE_AGE_SECONDS = 10

EXIT_OK = 0
EXIT_FAIL = 1
